==========
Riskmatrix
==========


.. image:: https://img.shields.io/pypi/v/riskmatrix.svg
        :target: https://pypi.python.org/pypi/riskmatrix

.. image:: https://img.shields.io/travis/slicerisk/riskmatrix.svg
        :target: https://travis-ci.org/slicerisk/riskmatrix

.. image:: https://readthedocs.org/projects/riskmatrix/badge/?version=latest
        :target: https://riskmatrix.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

A package to deal with risk matrix data.

* Free software: GNU General Public License v3
* Documentation: https://riskmatrix.readthedocs.io.

Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
